package com.miaxis.app.controller.test;

import java.util.List;
import io.swagger.annotations.*;
import com.miaxis.common.core.domain.Response;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.bind.annotation.ModelAttribute;
import com.miaxis.common.annotation.Log;
import com.miaxis.common.core.controller.BaseController;
import com.miaxis.common.enums.BusinessTypeEnum;
import com.miaxis.app.test.domain.TestTable;
import com.miaxis.app.test.service.ITestTableService;
import com.miaxis.common.utils.poi.ExcelUtil;
import com.miaxis.common.core.page.ResponsePageInfo;

/**
 * 【测试表】Controller
 *
 * @author miaxis
 * @date 2020-12-22
 */
@RestController
@RequestMapping("/test/table")
@Api(tags={"【测试表】Controller"})
public class TestTableController extends BaseController{
    @Autowired
    private ITestTableService testTableService;

    /**
     * 查询测试表列表
     */
    @PreAuthorize("@ss.hasPermi('test:table:list')")
    @GetMapping("/list")
    @ApiOperation("查询测试表列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum",value = "当前页码" ,dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize",value = "每页数据量" , dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<TestTable> list(@ModelAttribute TestTable testTable){
        startPage();
        List<TestTable> list = testTableService.selectTestTableList(testTable);
        return toResponsePageInfo(list);
    }

    /**
     * 导出测试表列表
     */
    @PreAuthorize("@ss.hasPermi('test:table:export')")
    @Log(title = "测试表", businessType = BusinessTypeEnum.EXPORT)
    @GetMapping("/export")
    @ApiOperation("导出测试表列表Excel")
    public Response<String> export(@ModelAttribute TestTable testTable){
        List<TestTable> list = testTableService.selectTestTableList(testTable);
        ExcelUtil<TestTable> util = new ExcelUtil<TestTable>(TestTable.class);
        return util.exportExcel(list, "table");
    }

    /**
     * 获取测试表详细信息
     */
    @PreAuthorize("@ss.hasPermi('test:table:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation("获取测试表详细信息")
    public Response<TestTable> getInfo(
            @ApiParam(name = "id", value = "测试表参数", required = true)
            @PathVariable("id") Long id
    ){
        return Response.success(testTableService.selectTestTableById(id));
    }

    /**
     * 新增测试表
     */
    @PreAuthorize("@ss.hasPermi('test:table:add')")
    @Log(title = "测试表", businessType = BusinessTypeEnum.INSERT)
    @PostMapping
    @ApiOperation("新增测试表")
    public Response<Integer> add(@RequestBody TestTable testTable){
        return toResponse(testTableService.insertTestTable(testTable));
    }

    /**
     * 修改测试表
     */
    @PreAuthorize("@ss.hasPermi('test:table:edit')")
    @Log(title = "测试表", businessType = BusinessTypeEnum.UPDATE)
    @PutMapping
    @ApiOperation("修改测试表")
    public Response<Integer> edit(@RequestBody TestTable testTable){
        return toResponse(testTableService.updateTestTable(testTable));
    }

    /**
     * 删除测试表
     */
    @PreAuthorize("@ss.hasPermi('test:table:remove')")
    @Log(title = "测试表", businessType = BusinessTypeEnum.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除测试表")
    public  Response<Integer> remove(
            @ApiParam(name = "ids", value = "测试表ids参数", required = true)
            @PathVariable Long[] ids
    ){
        return toResponse(testTableService.deleteTestTableByIds(ids));
    }
}
