package com.miaxis.app.test.service.impl;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.miaxis.common.utils.DateUtils;
import com.miaxis.common.utils.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.miaxis.app.test.mapper.TestTableMapper;
import com.miaxis.app.test.domain.TestTable;
import com.miaxis.app.test.service.ITestTableService;

/**
 * 测试表Service业务层处理
 *
 * @author miaxis
 * @date 2020-12-22
 */
@Service
public class TestTableServiceImpl extends ServiceImpl<TestTableMapper, TestTable> implements ITestTableService {
    @Autowired
    private TestTableMapper testTableMapper;

    /**
     * 查询测试表
     *
     * @param id 测试表ID
     * @return 测试表
     */
    @Override
    public TestTable selectTestTableById(Long id){
        return testTableMapper.selectTestTableById(id);
    }

    /**
     * 查询测试表列表
     *
     * @param testTable 测试表
     * @return 测试表
     */
    @Override
    public List<TestTable> selectTestTableList(TestTable testTable){
        return testTableMapper.selectTestTableList(testTable);
    }

    /**
     * 新增测试表
     *
     * @param testTable 测试表
     * @return 结果
     */
    @Override
    public int insertTestTable(TestTable testTable){
        testTable.setCreateTime(DateUtils.getNowDate());
        return testTableMapper.insertTestTable(testTable);
    }

    /**
     * 修改测试表
     *
     * @param testTable 测试表
     * @return 结果
     */
    @Override
    public int updateTestTable(TestTable testTable){
        testTable.setUpdateTime(DateUtils.getNowDate());
        return testTableMapper.updateTestTable(testTable);
    }

    /**
     * 批量删除测试表
     *
     * @param ids 需要删除的测试表ID
     * @return 结果
     */
    @Override
    public int deleteTestTableByIds(Long[] ids){
        return testTableMapper.deleteTestTableByIds(ids);
    }

    /**
     * 删除测试表信息
     *
     * @param id 测试表ID
     * @return 结果
     */
    @Override
    public int deleteTestTableById(Long id){
        return testTableMapper.deleteTestTableById(id);
    }
}
